<?php

if (!defined('ABSPATH')) {
    exit();
}



class PPT_Elementor_Tab_V2_Widget extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'ppt_tab_v2';
    }

    public function get_title()
    {
        return esc_html__('PPT Tab V2', 'ppt');
    }

    public function get_icon()
    {
        return 'eicon-tabs';
    }

    public function get_categories()
    {
        return ['ppt-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section('content_section', [
            'label' => esc_html__('Content', 'ppt'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('title', [
            'label' => esc_html__('Title', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);

        $repeater->add_control('text', [
            'label' => esc_html__('Text', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXTAREA,
            'label_block' => true,
        ]);

        $repeater->add_control('image', [
            'label' => esc_html__('Image', 'ppt'),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
            'label_block' => true,
        ]);


        $this->add_control('tabs', [
            'label' => esc_html__('Tabs', 'ppt'),
            'type' => \Elementor\Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'title_field' => '{{{ title }}}',
        ]);

        $this->end_controls_section();

        $this->start_controls_section('style_section', [
            'label' => esc_html__('Style', 'ppt'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);


        $this->add_control(
            'tab_align',
            [
                'label' => esc_html__( 'Tab Alignment', 'ppt' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'ppt' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'ppt' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'ppt' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'space-between' => [
                        'title' => esc_html__( 'Justify', 'ppt' ),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => 'center',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .ppt-v2-tab-item-controls-list' => 'justify-content: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-v2-tab-item-control' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_size',
            [
                'label' => esc_html__( 'Title Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .ppt-v2-tab-item-control' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        
        $this->add_control(
            'border_color',
            [
                'label' => esc_html__( 'Border Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-v2-tab-item-control[aria-selected=true]::after' => 'background-color: {{VALUE}} !important',
                ],
            ]
        );

        $this->add_control(
            'number_color',
            [
                'label' => esc_html__( 'Number Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-v2-tab-item-control::before' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'number_size',
            [
                'label' => esc_html__( 'Number Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .ppt-v2-tab-item-control::before' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label' => esc_html__( 'Text Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} figcaption.ppt-v2-tab-item-caption' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'text_size',
            [
                'label' => esc_html__( 'Text Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} figcaption.ppt-v2-tab-item-caption' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if ($settings['tabs']) { $counter = 1; ?>
            <div class="ppt-v2-tab-features ppt-v2-js-tabs" data-show-panel-class="ppt-v2-tab-item-show" data-hide-panel-class="ppt-v2-tab-item-hide">
                <ul class="ppt-v2-tab-item-controls-list ppt-v2-js-tabs-controls" aria-label="Tabs Interface">
                <?php foreach ($settings["tabs"] as $tab) { ?>
                <li class="ppt-v2-tab-item-controls-wrapper">
                  <a href="#ppt-v2-tab-features-<?php echo $counter; ?>" class="ppt-v2-tab-item-control" <?php echo ($counter == 1 ? 'aria-selected="true"' : ''); ?>><?php echo $tab['title']; ?></a>
                </li>
                <?php } ?>
              </ul>

              <div class="ppt-v2-tab-items ppt-v2-js-tabs-panels">
                  <?php foreach ($settings["tabs"] as $tab) { ?>
                <section id="ppt-v2-tab-features-<?php echo $counter; ?>" class="ppt-v2-tab-item ppt-v2-js-tabs-panel">
                  <figure>
                    <img class="ppt-v2-tab-item-image" src="<?php echo $tab['image']['url']; ?>" alt="<?php echo $tab['title']; ?>">
                    <figcaption class="ppt-v2-tab-item-caption"><?php echo $tab['text']; ?></figcaption>
                  </figure>
                </section>
                <?php $counter++; } ?>
              </div>
            </div>
        <?php }
    }
}
