<?php

if (!defined('ABSPATH')) {
    exit();
}



class PPT_Elementor_Tab_Widget extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'ppt_tab_v1';
    }

    public function get_title()
    {
        return esc_html__('PPT Tab ', 'ppt');
    }

    public function get_icon()
    {
        return 'eicon-tabs';
    }

    public function get_categories()
    {
        return ['ppt-category'];
    }

    protected function register_controls()
    {
        $this->start_controls_section('content_section', [
            'label' => esc_html__('Content', 'ppt'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);

        $repeater = new \Elementor\Repeater();

        $repeater->add_control('title', [
            'label' => esc_html__('Title', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'label_block' => true,
        ]);

        $repeater->add_control('text', [
            'label' => esc_html__('Text', 'ppt'),
            'type' => \Elementor\Controls_Manager::TEXTAREA,
            'label_block' => true,
        ]);

        $repeater->add_control('image', [
            'label' => esc_html__('Image', 'ppt'),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
            'label_block' => true,
        ]);


        $this->add_control('tabs', [
            'label' => esc_html__('Tabs', 'ppt'),
            'type' => \Elementor\Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'title_field' => '{{{ title }}}',
        ]);

        $this->end_controls_section();

        $this->start_controls_section('style_section', [
            'label' => esc_html__('Style', 'ppt'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]);


        $this->add_control(
            'title_align',
            [
                'label' => esc_html__( 'Title Alignment', 'ppt' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'ppt' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'ppt' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'ppt' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'center',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .ppt-v1-tab-item-control-title' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-v1-tab-item-control-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'title_size',
            [
                'label' => esc_html__( 'Title Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .ppt-v1-tab-item-control-title' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label' => esc_html__( 'Text Color', 'ppt' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ppt-v1-tab-item-control-description' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'text_size',
            [
                'label' => esc_html__( 'Text Font Size', 'ppt' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .ppt-v1-tab-item-control-description' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        if ($settings['tabs']) { $counter = 1; ?>

            <div class="ppt-v1-tab-details-view ppt-v1-tabs" data-show-panel-class="ppt-v1-tab-item-panel-display" data-hide-panel-class="ppt-v1-tab-attributes-conceal">
              <ul class="ppt-v1-tab-features-controls-list ppt-v1-js-tabs-controls" aria-label="Tabs navigation">
                <?php foreach ($settings["tabs"] as $tab) { ?>
                <li>
                  <a href="#ppt-v1-tab-item-<?php echo $counter; ?>" aria-controls="ppt-v1-tab-item-<?php echo $counter; ?>" id="tab-ppt-v1-tab-item-<?php echo $counter; ?>" class="ppt-v1-tab-item-control" <?php echo ($counter == 1 ? 'aria-selected="true"' : ''); ?>>
                    <span class="ppt-v1-tab-item-control-title"><?php echo $tab['title']; ?></span>
                    <span class="ppt-v1-tab-item-control-description"><?php echo $tab['text']; ?></span>
                  </a>
                </li>
                <?php } ?>
                <li class="ppt-v1-tab-item-text-gradient" aria-hidden="true"></li>
              </ul>

              <div class="ppt-v1-tab-item-panels ppt-v1-tabs-panels">
                  <?php foreach ($settings["tabs"] as $tab) { ?>
                <section id="ppt-v1-tab-item-<?php echo $counter; ?>" class="ppt-v1-tab-item-panel ppt-v1-tabs-panel">
                  <img class="ppt-v1-tab-item-img" src="<?php echo $tab['image']['url']; ?>" alt="<?php echo $tab['title']; ?>">
                </section>
                <?php $counter++; } ?>
              </div>
            </div>
        <?php }
    }
}
